@@ -1,11 +1,12 @@
 """
 Classes for querying which lines have changed based on a diff.
 """
-from abc import ABCMeta, abstractmethod
 import fnmatch
 import glob
 import os
 import re
+from abc import ABCMeta, abstractmethod
+
 from diff_cover.git_diff import GitDiffError
 
 
@@ -231,7 +232,7 @@ class GitDiffReporter(BaseDiffReporter):
                         result_dict[src_path] = [
                             line
                             for line in result_dict.get(src_path, [])
-                            if not line in deleted_lines
+                            if line not in deleted_lines
                         ] + added_lines
 
             # Eliminate repeats and order line numbers
