@@ -1,13 +1,9 @@
-from abc import ABCMeta, abstractmethod
-from collections import defaultdict, namedtuple
-
-
 import copy
-
+import os
 import re
 import sys
-import os
-
+from abc import ABCMeta, abstractmethod
+from collections import defaultdict, namedtuple
 
 from diff_cover.command_runner import execute, run_command_for_code
 
@@ -114,7 +110,7 @@ class QualityReporter(BaseViolationReporter):
         """
         Args:
             driver (QualityDriver) object that works with the underlying quality tool
-            reports (list[file]) pre-generated reports. If not provided the tool will be run instead.
+            reports (list[file]) pre-generated reports. If not provided the tool will be run instead
             options (str) options to be passed into the command
         """
         super().__init__(driver.name)
