@@ -11,16 +11,15 @@ try:
 except ImportError:
     # Python 3.9 onwards
     import xml.etree.ElementTree as etree
+
 from diff_cover.command_runner import run_command_for_code
 from diff_cover.git_path import GitPathTool
 from diff_cover.violationsreporters.base import (
-    BaseViolationReporter,
-    Violation,
-    RegexBasedDriver,
     QualityDriver,
+    RegexBasedDriver,
+    Violation,
 )
 
-
 """
     Report checkstyle violations.
 
@@ -130,7 +129,9 @@ class FindbugsXmlDriver(QualityDriver):
     def installed(self):
         """
         Method checks if the provided tool is installed.
-        Returns: boolean False: As findbugs analyses bytecode, it would be hard to run it from outside the build framework.
+        Returns:
+            boolean False: As findbugs analyses bytecode,
+            it would be hard to run it from outside the build framework.
         """
         return False
 
@@ -168,6 +169,8 @@ class PmdXmlDriver(QualityDriver):
     def installed(self):
         """
         Method checks if the provided tool is installed.
-        Returns: boolean False: As findbugs analyses bytecode, it would be hard to run it from outside the build framework.
+        Returns:
+            boolean False: As findbugs analyses bytecode,
+            it would be hard to run it from outside the build framework.
         """
         return False
